@@ -36,7 +36,8 @@ typedef enum {
 	GTH_FILE_LIST_TYPE_NORMAL,
 	GTH_FILE_LIST_TYPE_BROWSER,
 	GTH_FILE_LIST_TYPE_SELECTOR,
-	GTH_FILE_LIST_TYPE_NO_SELECTION
+	GTH_FILE_LIST_TYPE_NO_SELECTION,
+	GTH_FILE_LIST_TYPE_THUMBNAIL,
 } GthFileListType;
 
 #define GTH_TYPE_FILE_LIST            (gth_file_list_get_type ())
