@@ -119,7 +119,8 @@ _gtk_message_dialog_new (GtkWindow        *parent,
 					       escaped_message,
 					       escaped_secondary_message);
 		g_free (escaped_secondary_message);
-	} else
+	}
+	else
 		markup_text = g_strdup (escaped_message);
 	gtk_label_set_markup (GTK_LABEL (label), markup_text);
 	g_free (markup_text);
@@ -128,7 +129,7 @@ _gtk_message_dialog_new (GtkWindow        *parent,
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 
-	hbox = gtk_hbox_new (FALSE, 6);
+	hbox = gtk_hbox_new (FALSE, 18);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
 
 	gtk_box_pack_start (GTK_BOX (hbox), image,
@@ -697,14 +698,20 @@ static GdkPixbuf *
 get_file_icon_pixbuf (GFileIcon *icon,
 		      int        size)
 {
+	GdkPixbuf *pixbuf = NULL;
 	GFile     *file;
-	char      *filename;
-	GdkPixbuf *pixbuf;
 
 	file = g_file_icon_get_file (icon);
-	filename = g_file_get_path (file);
-	pixbuf = gdk_pixbuf_new_from_file_at_size (filename, size, -1, NULL);
-	g_free (filename);
+	if (file != NULL) {
+		char *filename;
+
+		filename = g_file_get_path (file);
+		if (filename != NULL)
+			pixbuf = gdk_pixbuf_new_from_file_at_size (filename, size, -1, NULL);
+
+		g_free (filename);
+	}
+
 	g_object_unref (file);
 
 	return pixbuf;
@@ -722,6 +729,7 @@ _g_icon_get_pixbuf (GIcon        *icon,
 	if (icon == NULL)
 		return NULL;
 
+	pixbuf = NULL;
 	if (G_IS_THEMED_ICON (icon))
 		pixbuf = get_themed_icon_pixbuf (G_THEMED_ICON (icon), size, theme);
 	if (G_IS_FILE_ICON (icon))
@@ -1013,21 +1021,31 @@ _gtk_tree_path_list_free (GList *list)
 int
 _gtk_paned_get_position2 (GtkPaned *paned)
 {
-	GtkRequisition requisition;
-	int            pos;
-	int            size;
+	int             pos;
+	GtkWidget      *w;
+	GtkRequisition  requisition;
+	int             size;
 
 	if (! GTK_WIDGET_VISIBLE (paned))
 		return 0;
 
 	pos = gtk_paned_get_position (paned);
+	if (pos == 0)
+		return 0;
 
-	gtk_window_get_size (GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (paned))), &(requisition.width), &(requisition.height));
+	w = gtk_widget_get_toplevel (GTK_WIDGET (paned));
+	if (! GTK_WIDGET_TOPLEVEL (w))
+		return 0;
+
+	gtk_window_get_size (GTK_WINDOW (w), &(requisition.width), &(requisition.height));
 	if (gtk_orientable_get_orientation (GTK_ORIENTABLE (paned)) == GTK_ORIENTATION_HORIZONTAL)
 		size = requisition.width;
 	else
 		size = requisition.height;
 
+	if (size == 0)
+		return 0;
+
 	return size - pos;
 }
 
@@ -1040,6 +1058,9 @@ _gtk_paned_set_position2 (GtkPaned *paned,
 	int        size;
 
 	top_level = gtk_widget_get_toplevel (GTK_WIDGET (paned));
+	if (! GTK_WIDGET_TOPLEVEL (top_level))
+		return;
+
 	if (gtk_orientable_get_orientation (GTK_ORIENTABLE (paned)) == GTK_ORIENTATION_HORIZONTAL)
 		size = top_level->allocation.width;
 	else
